static DH *get_dh512(void)
{
    static unsigned char dhp_512[] = {
        0xAE, 0xE1, 0x24, 0x4A, 0xB5, 0x8B, 0x37, 0x17, 0x41, 0xB3,
        0xD7, 0x1E, 0x29, 0x52, 0x77, 0x51, 0xCF, 0xE1, 0x1A, 0xC5,
        0xD7, 0x2A, 0xD6, 0xE8, 0x1D, 0xD6, 0xB2, 0xE5, 0xD8, 0x7D,
        0xA8, 0x85, 0x05, 0xF2, 0xE6, 0xC1, 0x61, 0xDB, 0x34, 0x99,
        0x61, 0x4D, 0x8A, 0x8A, 0xC5, 0xE4, 0xD6, 0x02, 0x24, 0x5C,
        0xC4, 0xED, 0xA7, 0x07, 0xCF, 0x1D, 0xB1, 0xA6, 0x69, 0x4D,
        0xA4, 0x14, 0x2F, 0xC3
    };
    static unsigned char dhg_512[] = {
        0x05
    };
    DH *dh = DH_new();
    BIGNUM *p, *g;

    if (dh == NULL)
        return NULL;
    p = BN_bin2bn(dhp_512, sizeof(dhp_512), NULL);
    g = BN_bin2bn(dhg_512, sizeof(dhg_512), NULL);
    if (p == NULL || g == NULL
            || !DH_set0_pqg(dh, p, NULL, g)) {
        DH_free(dh);
        BN_free(p);
        BN_free(g);
        return NULL;
    }
    return dh;
}
static DH *get_dh2048(void)
{
    static unsigned char dhp_2048[] = {
        0x8B, 0xC9, 0xFA, 0x43, 0x38, 0xCA, 0xA7, 0x5C, 0x02, 0x34,
        0xFF, 0xDF, 0x80, 0x2A, 0x99, 0x4A, 0x2A, 0x11, 0x64, 0x3C,
        0x0A, 0x7F, 0x1D, 0x2D, 0x23, 0xCA, 0x4E, 0x08, 0x0A, 0x44,
        0x1A, 0xB9, 0x62, 0x1B, 0xD1, 0x96, 0x83, 0x69, 0x06, 0x50,
        0xDC, 0x8A, 0x8C, 0xBE, 0x65, 0x12, 0xAF, 0xB2, 0xB8, 0xD7,
        0xFA, 0x07, 0x36, 0x67, 0xC9, 0x2C, 0x16, 0x9D, 0xA2, 0x12,
        0x14, 0xA0, 0x3A, 0xAB, 0x50, 0x5C, 0x2B, 0xB5, 0x9F, 0x20,
        0x9C, 0x99, 0xEA, 0x23, 0xA8, 0x0E, 0x00, 0x5C, 0xD8, 0x98,
        0x7F, 0x1D, 0x7B, 0xAE, 0x38, 0xAF, 0xA3, 0xCA, 0x7E, 0x5F,
        0x34, 0xAA, 0x0A, 0xEB, 0x81, 0x04, 0x89, 0x40, 0x42, 0x7C,
        0x0F, 0x5B, 0xF1, 0xB3, 0x4B, 0xBC, 0x9C, 0x28, 0x37, 0x92,
        0xAE, 0xF5, 0x05, 0x82, 0xBB, 0xCD, 0x4F, 0x51, 0x12, 0x3F,
        0x1E, 0x50, 0x78, 0x8B, 0x78, 0xCA, 0xBB, 0xC0, 0x7E, 0x49,
        0x74, 0x89, 0xD6, 0x7E, 0x49, 0xFF, 0x81, 0x5E, 0x8B, 0xBC,
        0x7A, 0xD5, 0xC4, 0x37, 0x32, 0x0B, 0xE0, 0xCB, 0x0C, 0x20,
        0xB4, 0x84, 0x2B, 0x04, 0x2F, 0x3A, 0x6E, 0xF5, 0xDC, 0xF1,
        0x15, 0x28, 0xFB, 0xCB, 0xA9, 0x4A, 0x93, 0x11, 0xB2, 0x54,
        0xC3, 0xCF, 0x74, 0xB4, 0x45, 0xD3, 0x45, 0x5C, 0x76, 0x29,
        0x9C, 0xD9, 0x54, 0x84, 0x98, 0x60, 0x3F, 0x8A, 0xCE, 0xB1,
        0x13, 0x0C, 0x62, 0x49, 0xD7, 0x86, 0x8F, 0xB8, 0x03, 0x41,
        0x95, 0x38, 0x89, 0xCE, 0xB8, 0x9B, 0xF9, 0x3D, 0x3D, 0x1F,
        0x35, 0x0F, 0x84, 0x6D, 0xE0, 0x6C, 0xB6, 0xE7, 0x1C, 0xE6,
        0x0E, 0x1D, 0x6B, 0x46, 0xBC, 0x45, 0x0A, 0x59, 0xC1, 0x3F,
        0x2E, 0xE5, 0xCD, 0x71, 0x29, 0x2E, 0x56, 0xDF, 0xF9, 0xC0,
        0xFE, 0xD8, 0x48, 0x3C, 0x1B, 0x96, 0xA7, 0xE6, 0x0C, 0xEA,
        0x94, 0x02, 0xEB, 0x04, 0x82, 0x13
    };
    static unsigned char dhg_2048[] = {
        0x05
    };
    DH *dh = DH_new();
    BIGNUM *p, *g;

    if (dh == NULL)
        return NULL;
    p = BN_bin2bn(dhp_2048, sizeof(dhp_2048), NULL);
    g = BN_bin2bn(dhg_2048, sizeof(dhg_2048), NULL);
    if (p == NULL || g == NULL
            || !DH_set0_pqg(dh, p, NULL, g)) {
        DH_free(dh);
        BN_free(p);
        BN_free(g);
        return NULL;
    }
    return dh;
}
